@@ -3,8 +3,8 @@
 # Author: Andrew Jewett (jewett.aij at g mail)
 #         http://www.moltemplate.org
 #         http://www.chem.ucsb.edu/~sheagroup
-# License: 3-clause BSD License  (See LICENSE.TXT)
-# Copyright (c) 2011, Regents of the University of California
+# License: MIT License  (See LICENSE.md)
+# Copyright (c) 2013, Regents of the University of California
 # All rights reserved.
 
 """
@@ -29,8 +29,8 @@ Additional LAMMPS-specific features may be added in the future.
 """
 
 g_program_name = __file__.split('/')[-1]  # ='lttree.py'
-g_date_str = '2018-10-16'
-g_version_str = '0.80.0'
+g_date_str = '2020-3-10'
+g_version_str = '0.80.2'
 
 
 import sys
@@ -44,7 +44,7 @@ try:
         WriteVarBindingsFile, StaticObj, InstanceObj, \
         BasicUI, ScopeBegin, ScopeEnd, WriteFileCommand, Render
     from .ttree_lex import InputError, TextBlock, DeleteLinesWithBadVars, \
-        TemplateLexer, TableFromTemplate, VarRef, TextBlock
+        TemplateLexer, TableFromTemplate, VarRef, TextBlock, ErrorLeader
     from .lttree_styles import AtomStyle2ColNames, ColNames2AidAtypeMolid, \
         ColNames2Coords, ColNames2Vects, \
         data_atoms, data_prefix, data_masses, \
@@ -60,7 +60,7 @@ try:
         data_boundary, data_pbc, data_prefix_no_space, in_init, in_settings, \
         in_prefix
     from .ttree_matrix_stack import AffineTransform, MultiAffineStack, \
-        LinTransform
+        LinTransform, Matrix2Quaternion, MultQuat
 except (ImportError, SystemError, ValueError):
     # not installed as a package
     from ttree import *
@@ -944,8 +944,17 @@ def main():
         sys.stderr.write(' done\n')
 
     except (ValueError, InputError) as err:
-        sys.stderr.write('\n\n' + str(err) + '\n')
-        sys.exit(-1)
+        if isinstance(err, ValueError):
+            sys.stderr.write('Error converting string to numeric format.\n'
+                             '      This sometimes means you have neglected to specify the atom style\n'
+                             '      (using the \"-atomstyle\" command).  Alternatively it could indicate\n'
+                             '      that the moltemplate file contains non-numeric text in one of the\n'
+                             '      .move(), .rot(), .scale(), .matrix(), or .quat() commands. If neither of\n'
+                             '      these scenarios apply, please report this bug. (jewett.aij at gmail.com)\n')
+            sys.exit(-1)
+        else:
+            sys.stderr.write('\n\n' + str(err) + '\n')
+            sys.exit(-1)
 
     return
 
